<?php

namespace Drupal\sfc\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;

/**
 * Enables projects to quickly define routes for components.
 */
class ComponentController extends ControllerBase {

  /**
   * Generic controller for rendering components.
   *
   * To use this method, define a route like:
   *
   * my_route:
   *   path: /homepage
   *   defaults:
   *     _controller: \Drupal\sfc\Controller\ComponentController::build
   *     component_id: homepage
   *   requirements:
   *     _access: 'TRUE'
   *
   * Other route parameters will be passed directly into context, and the
   * current request will be available in the "request" key.
   *
   * @param string $component_id
   *   The component ID.
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The current request.
   *
   * @return array
   *   The render array.
   */
  public function build($component_id, Request $request) {
    $context = $request->attributes->all();
    $context['request'] = $request;
    return [
      '#type' => 'sfc',
      '#component_id' => $component_id,
      '#context' => $context,
    ];
  }

}
